You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nuttx.apache.org by xi...@apache.org on 2023/08/19 10:40:37 UTC

[nuttx] branch master updated (891e05d99a -> 2d8b96e562)

This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/nuttx.git


    from 891e05d99a include: move clockid_t and time[r]_t define to sys/types.h
     new e25fcb3bd5 esp32s3_devkit/sta_softap: Disable SMP on `defconfig` temporarily
     new 382debc996 esp32_c3_s3/wifi_ble: Use `nxsem_trywait` to take semphr from ISR
     new 2d8b96e562 esp32-devkitc/blewifi: Unset `DEFAULT_SMALL` and debugging configs

The 3 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 arch/risc-v/src/esp32c3/esp32c3_ble_adapter.c      | 15 +++--
 arch/risc-v/src/esp32c3/esp32c3_wifi_adapter.c     | 29 ++++----
 arch/xtensa/src/esp32/esp32_ble_adapter.c          | 19 ++++--
 arch/xtensa/src/esp32/esp32_wifi_adapter.c         | 35 +++++-----
 arch/xtensa/src/esp32s3/esp32s3_ble_adapter.c      |  8 ++-
 arch/xtensa/src/esp32s3/esp32s3_wifi_adapter.c     | 29 ++++----
 .../esp32/esp32-devkitc/configs/blewifi/defconfig  | 78 +++++-----------------
 .../esp32s3-devkit/configs/sta_softap/defconfig    |  3 +-
 8 files changed, 99 insertions(+), 117 deletions(-)


[nuttx] 02/03: esp32_c3_s3/wifi_ble: Use `nxsem_trywait` to take semphr from ISR

Posted by xi...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/nuttx.git

commit 382debc996518b63fed2fd893e12e2aca2ece90f
Author: Tiago Medicci Serrano <ti...@espressif.com>
AuthorDate: Fri Aug 18 08:56:11 2023 -0300

    esp32_c3_s3/wifi_ble: Use `nxsem_trywait` to take semphr from ISR
    
    Use the non-blocking `nxsem_trywait` to try to take the semaphore
    during the interrupt handler.
---
 arch/risc-v/src/esp32c3/esp32c3_ble_adapter.c  | 15 ++++++-----
 arch/risc-v/src/esp32c3/esp32c3_wifi_adapter.c | 29 ++++++++++++---------
 arch/xtensa/src/esp32/esp32_ble_adapter.c      | 19 +++++++++++---
 arch/xtensa/src/esp32/esp32_wifi_adapter.c     | 35 +++++++++++++++-----------
 arch/xtensa/src/esp32s3/esp32s3_ble_adapter.c  |  8 +++---
 arch/xtensa/src/esp32s3/esp32s3_wifi_adapter.c | 29 ++++++++++++---------
 6 files changed, 83 insertions(+), 52 deletions(-)

diff --git a/arch/risc-v/src/esp32c3/esp32c3_ble_adapter.c b/arch/risc-v/src/esp32c3/esp32c3_ble_adapter.c
index dce292f5d6..d05cd5a63b 100644
--- a/arch/risc-v/src/esp32c3/esp32c3_ble_adapter.c
+++ b/arch/risc-v/src/esp32c3/esp32c3_ble_adapter.c
@@ -828,8 +828,9 @@ static void semphr_delete_wrapper(void *semphr)
 
 static int semphr_take_from_isr_wrapper(void *semphr, void *hptw)
 {
-  DEBUGPANIC();
-  return false;
+  *(int *)hptw = 0;
+
+  return esp_errno_trans(nxsem_trywait(semphr));
 }
 
 /****************************************************************************
@@ -921,10 +922,6 @@ static int semphr_take_wrapper(void *semphr, uint32_t block_time_ms)
   if (block_time_ms == OSI_FUNCS_TIME_BLOCKING)
     {
       ret = nxsem_wait(&bt_sem->sem);
-      if (ret)
-        {
-          wlerr("Failed to wait sem\n");
-        }
     }
   else
     {
@@ -938,6 +935,12 @@ static int semphr_take_wrapper(void *semphr, uint32_t block_time_ms)
         }
     }
 
+  if (ret)
+    {
+      wlerr("ERROR: Failed to wait sem in %lu ticks. Error=%d\n",
+            MSEC2TICK(block_time_ms), ret);
+    }
+
   return esp_errno_trans(ret);
 }
 
diff --git a/arch/xtensa/src/esp32/esp32_ble_adapter.c b/arch/xtensa/src/esp32/esp32_ble_adapter.c
index dc33fea4d8..4c6ff3b65c 100644
--- a/arch/xtensa/src/esp32/esp32_ble_adapter.c
+++ b/arch/xtensa/src/esp32/esp32_ble_adapter.c
@@ -1192,6 +1192,8 @@ static void semphr_delete_wrapper(void *semphr)
 
 static int IRAM_ATTR semphr_take_from_isr_wrapper(void *semphr, void *hptw)
 {
+  *(int *)hptw = 0;
+
   return esp_errno_trans(nxsem_trywait(semphr));
 }
 
@@ -1267,14 +1269,23 @@ static int semphr_take_wrapper(void *semphr, uint32_t block_time_ms)
   if (block_time_ms == OSI_FUNCS_TIME_BLOCKING)
     {
       ret = nxsem_wait(sem);
-      if (ret)
+    }
+  else
+    {
+      if (block_time_ms > 0)
+        {
+          ret = nxsem_tickwait(sem, MSEC2TICK(block_time_ms));
+        }
+      else
         {
-          wlerr("Failed to wait sem %d\n", ret);
+          ret = nxsem_trywait(sem);
         }
     }
-  else
+
+  if (ret)
     {
-      ret = nxsem_tickwait(sem, MSEC2TICK(block_time_ms));
+      wlerr("ERROR: Failed to wait sem in %u ticks. Error=%d\n",
+            MSEC2TICK(block_time_ms), ret);
     }
 
   return esp_errno_trans(ret);
diff --git a/arch/xtensa/src/esp32s3/esp32s3_ble_adapter.c b/arch/xtensa/src/esp32s3/esp32s3_ble_adapter.c
index 520dc9e938..31fc7c9b37 100644
--- a/arch/xtensa/src/esp32s3/esp32s3_ble_adapter.c
+++ b/arch/xtensa/src/esp32s3/esp32s3_ble_adapter.c
@@ -894,8 +894,9 @@ static void semphr_delete_wrapper(void *semphr)
 
 static int IRAM_ATTR semphr_take_from_isr_wrapper(void *semphr, void *hptw)
 {
-  DEBUGPANIC();
-  return false;
+  *(int *)hptw = 0;
+
+  return esp_errno_trans(nxsem_trywait(semphr));
 }
 
 /****************************************************************************
@@ -988,7 +989,8 @@ static int semphr_take_wrapper(void *semphr, uint32_t block_time_ms)
 
   if (ret)
     {
-      wlerr("Failed to take sem error=%d\n", ret);
+      wlerr("ERROR: Failed to wait sem in %u ticks. Error=%d\n",
+            MSEC2TICK(block_time_ms), ret);
     }
 
   return esp_errno_trans(ret);
diff --git a/boards/xtensa/esp32s3/esp32s3-devkit/configs/sta_softap/defconfig b/boards/xtensa/esp32s3/esp32s3-devkit/configs/sta_softap/defconfig
index 1bfcec92d5..b34e2671e9 100644
--- a/boards/xtensa/esp32s3/esp32s3-devkit/configs/sta_softap/defconfig
+++ b/boards/xtensa/esp32s3/esp32s3-devkit/configs/sta_softap/defconfig
@@ -72,9 +72,8 @@ CONFIG_RR_INTERVAL=200
 CONFIG_SCHED_LPWORK=y
 CONFIG_SCHED_WAITPID=y
 CONFIG_SIG_DEFAULT=y
-CONFIG_SMP=y
-CONFIG_SMP_NCPUS=2
 CONFIG_SPIFFS_NAME_MAX=128
+CONFIG_SPINLOCK=y
 CONFIG_START_DAY=6
 CONFIG_START_MONTH=12
 CONFIG_START_YEAR=2011


[nuttx] 03/03: esp32-devkitc/blewifi: Unset `DEFAULT_SMALL` and debugging configs

Posted by xi...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/nuttx.git

commit 2d8b96e5627fb3ef770c87d6de3c83dff94db51b
Author: Tiago Medicci Serrano <ti...@espressif.com>
AuthorDate: Fri Aug 18 15:12:41 2023 -0300

    esp32-devkitc/blewifi: Unset `DEFAULT_SMALL` and debugging configs
    
    Following the pattern of the others `defconfigs`, disable debugging
    configs and `CONFIG_DEFAULT_SMALL`.
---
 .../esp32/esp32-devkitc/configs/blewifi/defconfig  | 78 +++++-----------------
 1 file changed, 15 insertions(+), 63 deletions(-)

diff --git a/boards/xtensa/esp32/esp32-devkitc/configs/blewifi/defconfig b/boards/xtensa/esp32/esp32-devkitc/configs/blewifi/defconfig
index adc0d40343..c988cbc1d7 100644
--- a/boards/xtensa/esp32/esp32-devkitc/configs/blewifi/defconfig
+++ b/boards/xtensa/esp32/esp32-devkitc/configs/blewifi/defconfig
@@ -6,47 +6,9 @@
 # modifications.
 #
 # CONFIG_ARCH_LEDS is not set
-# CONFIG_DISABLE_ENVIRON is not set
-# CONFIG_DISABLE_MQUEUE is not set
-# CONFIG_DISABLE_POSIX_TIMERS is not set
-# CONFIG_DISABLE_PSEUDOFS_OPERATIONS is not set
-# CONFIG_DISABLE_PTHREAD is not set
-# CONFIG_FS_PROCFS_EXCLUDE_BLOCKS is not set
-# CONFIG_FS_PROCFS_EXCLUDE_ENVIRON is not set
-# CONFIG_FS_PROCFS_EXCLUDE_IOBINFO is not set
-# CONFIG_FS_PROCFS_EXCLUDE_MEMDUMP is not set
-# CONFIG_FS_PROCFS_EXCLUDE_MEMINFO is not set
-# CONFIG_FS_PROCFS_EXCLUDE_MOUNT is not set
-# CONFIG_FS_PROCFS_EXCLUDE_MOUNTS is not set
-# CONFIG_FS_PROCFS_EXCLUDE_NET is not set
-# CONFIG_FS_PROCFS_EXCLUDE_PARTITIONS is not set
-# CONFIG_FS_PROCFS_EXCLUDE_PROCESS is not set
-# CONFIG_FS_PROCFS_EXCLUDE_SMARTFS is not set
-# CONFIG_FS_PROCFS_EXCLUDE_UPTIME is not set
-# CONFIG_FS_PROCFS_EXCLUDE_USAGE is not set
-# CONFIG_FS_PROCFS_EXCLUDE_VERSION is not set
-# CONFIG_NSH_DISABLEBG is not set
-# CONFIG_NSH_DISABLESCRIPT is not set
-# CONFIG_NSH_DISABLE_ARP is not set
-# CONFIG_NSH_DISABLE_BASENAME is not set
-# CONFIG_NSH_DISABLE_CMP is not set
-# CONFIG_NSH_DISABLE_DD is not set
-# CONFIG_NSH_DISABLE_DF is not set
-# CONFIG_NSH_DISABLE_DIRNAME is not set
-# CONFIG_NSH_DISABLE_EXEC is not set
-# CONFIG_NSH_DISABLE_GET is not set
-# CONFIG_NSH_DISABLE_HEXDUMP is not set
-# CONFIG_NSH_DISABLE_ITEF is not set
-# CONFIG_NSH_DISABLE_LOOPS is not set
-# CONFIG_NSH_DISABLE_LOSETUP is not set
-# CONFIG_NSH_DISABLE_MKRD is not set
-# CONFIG_NSH_DISABLE_MKSMARTFS is not set
-# CONFIG_NSH_DISABLE_PUT is not set
-# CONFIG_NSH_DISABLE_SEMICOLON is not set
-# CONFIG_NSH_DISABLE_TIME is not set
-# CONFIG_NSH_DISABLE_UNAME is not set
-# CONFIG_NSH_DISABLE_WGET is not set
-# CONFIG_NSH_DISABLE_XD is not set
+# CONFIG_NDEBUG is not set
+# CONFIG_NSH_ARGCAT is not set
+# CONFIG_NSH_CMDOPT_HEXDUMP is not set
 CONFIG_ALLOW_BSD_COMPONENTS=y
 CONFIG_ARCH="xtensa"
 CONFIG_ARCH_BOARD="esp32-devkitc"
@@ -58,54 +20,43 @@ CONFIG_ARCH_CHIP_ESP32WROVER=y
 CONFIG_ARCH_INTERRUPTSTACK=4096
 CONFIG_ARCH_STACKDUMP=y
 CONFIG_ARCH_XTENSA=y
+CONFIG_BCH=y
+CONFIG_BOARDCTL_RESET=y
 CONFIG_BOARD_LOOPSPERMSEC=16717
 CONFIG_BTSAK=y
 CONFIG_BUILTIN=y
-CONFIG_DEBUG_ERROR=y
-CONFIG_DEBUG_FEATURES=y
-CONFIG_DEBUG_FULLOPT=y
-CONFIG_DEBUG_INFO=y
-CONFIG_DEBUG_SYMBOLS=y
-CONFIG_DEBUG_WARN=y
-CONFIG_DEBUG_WIRELESS=y
-CONFIG_DEBUG_WIRELESS_ERROR=y
-CONFIG_DEBUG_WIRELESS_INFO=y
-CONFIG_DEBUG_WIRELESS_WARN=y
-CONFIG_DEFAULT_SMALL=y
 CONFIG_DEFAULT_TASK_STACKSIZE=4096
 CONFIG_DEV_URANDOM=y
+CONFIG_DISABLE_MQUEUE_NOTIFICATION=y
 CONFIG_DRIVERS_BLUETOOTH=y
 CONFIG_DRIVERS_IEEE80211=y
 CONFIG_DRIVERS_WIRELESS=y
 CONFIG_ESP32_BLE=y
 CONFIG_ESP32_RT_TIMER_TASK_STACK_SIZE=4096
 CONFIG_ESP32_SPIFLASH=y
-CONFIG_ESP32_SPIFLASH_SMARTFS=y
+CONFIG_ESP32_SPIFLASH_SPIFFS=y
 CONFIG_ESP32_STORAGE_MTD_SIZE=0x80000
 CONFIG_ESP32_UART0=y
 CONFIG_ESP32_WIFI=y
 CONFIG_ESP32_WIFI_BT_COEXIST=y
 CONFIG_ESP32_WIFI_STATION_SOFTAP=y
+CONFIG_EXAMPLES_DHCPD=y
 CONFIG_EXAMPLE_POWER_SAVE_MIN_MODEM=y
-CONFIG_FILE_STREAM=y
 CONFIG_FS_PROCFS=y
-CONFIG_FS_SPIFFS=y
 CONFIG_HAVE_CXX=y
 CONFIG_HAVE_CXXINITIALIZE=y
 CONFIG_IDLETHREAD_STACKSIZE=3072
 CONFIG_INIT_ENTRYPOINT="nsh_main"
 CONFIG_INTELHEX_BINARY=y
-CONFIG_LIBC_LONG_LONG=y
-CONFIG_LIBM_TOOLCHAIN=y
 CONFIG_MM_REGIONS=3
 CONFIG_NAME_MAX=48
 CONFIG_NETDB_DNSCLIENT=y
-CONFIG_NETDB_DNSCLIENT_ENTRIES=8
 CONFIG_NETDB_DNSCLIENT_NAMESIZE=64
 CONFIG_NETDEV_LATEINIT=y
 CONFIG_NETDEV_PHY_IOCTL=y
 CONFIG_NETDEV_WIRELESS_IOCTL=y
 CONFIG_NETUTILS_CJSON=y
+CONFIG_NETUTILS_DHCPD=y
 CONFIG_NETUTILS_IPERF=y
 CONFIG_NETUTILS_TELNETD=y
 CONFIG_NET_BLUETOOTH=y
@@ -121,18 +72,20 @@ CONFIG_NET_TCP_WRITE_BUFFERS=y
 CONFIG_NET_UDP=y
 CONFIG_NSH_ARCHINIT=y
 CONFIG_NSH_BUILTIN_APPS=y
+CONFIG_NSH_FILEIOSIZE=512
 CONFIG_NSH_LINELEN=300
-CONFIG_NSH_TELNET=y
+CONFIG_NSH_READLINE=y
 CONFIG_POSIX_SPAWN_DEFAULT_STACKSIZE=2048
-CONFIG_PTHREAD_MUTEX_ROBUST=y
+CONFIG_PREALLOC_MQ_IRQ_MSGS=4
+CONFIG_PREALLOC_MQ_MSGS=4
+CONFIG_PREALLOC_TIMERS=4
 CONFIG_PTHREAD_MUTEX_TYPES=y
 CONFIG_RAM_SIZE=114688
 CONFIG_RAM_START=0x20000000
 CONFIG_RR_INTERVAL=200
 CONFIG_SCHED_WAITPID=y
 CONFIG_SIG_DEFAULT=y
-CONFIG_SMARTFS_ALIGNED_ACCESS=y
-CONFIG_SMARTFS_MAXNAMLEN=48
+CONFIG_SIG_PREALLOC_IRQ_ACTIONS=4
 CONFIG_SPI=y
 CONFIG_SPIFFS_NAME_MAX=48
 CONFIG_SPINLOCK=y
@@ -143,7 +96,6 @@ CONFIG_SYSLOG_BUFFER=y
 CONFIG_SYSTEM_DHCPC_RENEW=y
 CONFIG_SYSTEM_NSH=y
 CONFIG_SYSTEM_PING=y
-CONFIG_SYSTEM_TELNETD=y
 CONFIG_TLS_TASK_NELEM=4
 CONFIG_UART0_SERIAL_CONSOLE=y
 CONFIG_WIRELESS=y
diff --git a/arch/risc-v/src/esp32c3/esp32c3_wifi_adapter.c b/arch/risc-v/src/esp32c3/esp32c3_wifi_adapter.c
index 46b41a0c57..86a7915388 100644
--- a/arch/risc-v/src/esp32c3/esp32c3_wifi_adapter.c
+++ b/arch/risc-v/src/esp32c3/esp32c3_wifi_adapter.c
@@ -1191,34 +1191,39 @@ static void esp_semphr_delete(void *semphr)
  *   Wait semaphore within a certain period of time
  *
  * Input Parameters:
  *   semphr - Semaphore data pointer
  *   ticks  - Wait system ticks
  *
  * Returned Value:
  *   True if success or false if fail
  *
  ****************************************************************************/
 
-static int32_t esp_semphr_take(void *semphr, uint32_t ticks)
+static int32_t esp_semphr_take(void *semphr, uint32_t block_time_tick)
 {
   int ret;
   sem_t *sem = (sem_t *)semphr;
 
-  if (ticks == OSI_FUNCS_TIME_BLOCKING)
+  if (block_time_tick == OSI_FUNCS_TIME_BLOCKING)
     {
       ret = nxsem_wait(sem);
-      if (ret)
-        {
-          wlerr("ERROR: Failed to wait sem\n");
-        }
     }
   else
     {
-      ret = nxsem_tickwait(sem, ticks);
-      if (ret)
+      if (block_time_tick > 0)
         {
-          wlerr("ERROR: Failed to wait sem in %lu ticks\n", ticks);
+          ret = nxsem_tickwait(sem, block_time_tick);
         }
+      else
+        {
+          ret = nxsem_trywait(sem);
+        }
+    }
+
+  if (ret)
+    {
+      wlerr("ERROR: Failed to wait sem in %lu ticks. Error=%d\n",
+            block_time_tick, ret);
     }
 
   return osi_errno_trans(ret);
@@ -1271,7 +1276,7 @@ static int32_t esp_semphr_take_from_isr(void *semphr, void *hptw)
 {
   *(int *)hptw = 0;
 
-  return esp_semphr_take(semphr, 0);
+  return esp_errno_trans(nxsem_trywait(semphr));
 }
 
 /****************************************************************************
@@ -1191,34 +1191,39 @@ static void esp_semphr_delete(void *semphr)
  *
  * Input Parameters:
- *   semphr - Semaphore data pointer
- *   ticks  - Wait system ticks
+ *   semphr          - Semaphore data pointer
+ *   block_time_tick - Wait system ticks
  *
  * Returned Value:
diff --git a/arch/xtensa/src/esp32/esp32_wifi_adapter.c b/arch/xtensa/src/esp32/esp32_wifi_adapter.c
index 3c1d5c9ef0..0d2e5066e3 100644
--- a/arch/xtensa/src/esp32/esp32_wifi_adapter.c
+++ b/arch/xtensa/src/esp32/esp32_wifi_adapter.c
@@ -1113,34 +1113,39 @@ static void esp_semphr_delete(void *semphr)
  *   Wait semaphore within a certain period of time
  *
  * Input Parameters:
  *   semphr - Semaphore data pointer
  *   ticks  - Wait system ticks
  *
  * Returned Value:
  *   True if success or false if fail
  *
  ****************************************************************************/
 
-static int32_t esp_semphr_take(void *semphr, uint32_t ticks)
+static int32_t esp_semphr_take(void *semphr, uint32_t block_time_tick)
 {
   int ret;
   sem_t *sem = (sem_t *)semphr;
 
-  if (ticks == OSI_FUNCS_TIME_BLOCKING)
+  if (block_time_tick == OSI_FUNCS_TIME_BLOCKING)
     {
       ret = nxsem_wait(sem);
-      if (ret)
-        {
-          wlerr("Failed to wait sem\n");
-        }
     }
   else
     {
-      ret = nxsem_tickwait(sem, ticks);
-      if (ret)
+      if (block_time_tick > 0)
         {
-          wlerr("Failed to wait sem in %d ticks\n", ticks);
+          ret = nxsem_tickwait(sem, block_time_tick);
         }
+      else
+        {
+          ret = nxsem_trywait(sem);
+        }
+    }
+
+  if (ret)
+    {
+      wlerr("ERROR: Failed to wait sem in %u ticks. Error=%d\n",
+            block_time_tick, ret);
     }
 
   return osi_errno_trans(ret);
@@ -1189,11 +1194,11 @@ static int32_t esp_semphr_give(void *semphr)
  *
  ****************************************************************************/
 
-static int32_t esp_semphr_take_from_isr(void *semphr, void *hptw)
+static int32_t IRAM_ATTR esp_semphr_take_from_isr(void *semphr, void *hptw)
 {
   *(int *)hptw = 0;
 
-  return esp_semphr_take(semphr, 0);
+  return osi_errno_trans(nxsem_trywait(semphr));
 }
 
 /****************************************************************************
@@ -1210,11 +1215,11 @@ static int32_t esp_semphr_take_from_isr(void *semphr, void *hptw)
  *
  ****************************************************************************/
 
-static int32_t esp_semphr_give_from_isr(void *semphr, void *hptw)
+static int32_t IRAM_ATTR esp_semphr_give_from_isr(void *semphr, void *hptw)
 {
   *(int *)hptw = 0;
 
-  return esp_semphr_give(semphr);
+  return osi_errno_trans(nxsem_post(semphr));
 }
 
 /****************************************************************************
@@ -1113,34 +1113,39 @@ static void esp_semphr_delete(void *semphr)
  *
  * Input Parameters:
- *   semphr - Semaphore data pointer
- *   ticks  - Wait system ticks
+ *   semphr          - Semaphore data pointer
+ *   block_time_tick - Wait system ticks
  *
  * Returned Value:
diff --git a/arch/xtensa/src/esp32s3/esp32s3_wifi_adapter.c b/arch/xtensa/src/esp32s3/esp32s3_wifi_adapter.c
index b794f6b203..79c145bd5e 100644
--- a/arch/xtensa/src/esp32s3/esp32s3_wifi_adapter.c
+++ b/arch/xtensa/src/esp32s3/esp32s3_wifi_adapter.c
@@ -1087,34 +1087,39 @@ static void esp_semphr_delete(void *semphr)
  *   Wait semaphore within a certain period of time
  *
  * Input Parameters:
  *   semphr - Semaphore data pointer
  *   ticks  - Wait system ticks
  *
  * Returned Value:
  *   True if success or false if fail
  *
  ****************************************************************************/
 
-static int32_t esp_semphr_take(void *semphr, uint32_t ticks)
+static int32_t esp_semphr_take(void *semphr, uint32_t block_time_tick)
 {
   int ret;
   sem_t *sem = (sem_t *)semphr;
 
-  if (ticks == OSI_FUNCS_TIME_BLOCKING)
+  if (block_time_tick == OSI_FUNCS_TIME_BLOCKING)
     {
       ret = nxsem_wait(sem);
-      if (ret)
-        {
-          wlerr("Failed to wait sem\n");
-        }
     }
   else
     {
-      ret = nxsem_tickwait(sem, ticks);
-      if (ret)
+      if (block_time_tick > 0)
         {
-          wlerr("Failed to wait sem in %d ticks\n", ticks);
+          ret = nxsem_tickwait(sem, block_time_tick);
         }
+      else
+        {
+          ret = nxsem_trywait(sem);
+        }
+    }
+
+  if (ret)
+    {
+      wlerr("ERROR: Failed to wait sem in %u ticks. Error=%d\n",
+            block_time_tick, ret);
     }
 
   return osi_errno_trans(ret);
@@ -2289,7 +2294,7 @@ static int IRAM_ATTR semphr_take_from_isr_wrapper(void *semphr, void *hptw)
 {
   *(int *)hptw = 0;
 
-  return esp_semphr_take(semphr, 0);
+  return osi_errno_trans(nxsem_trywait(semphr));
 }
 
 /****************************************************************************


[nuttx] 01/03: esp32s3_devkit/sta_softap: Disable SMP on `defconfig` temporarily

Posted by xi...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/nuttx.git

commit e25fcb3bd53fb36572cba7e2ccc6a873c75ed10c
Author: Tiago Medicci Serrano <ti...@espressif.com>
AuthorDate: Fri Aug 18 10:16:32 2023 -0300

    esp32s3_devkit/sta_softap: Disable SMP on `defconfig` temporarily
    
    There is a known bug while using the Station + softAP mode with SMP
    mode enabled. Disable it temporarily until the bug is properly
    fixed.
---
 boards/xtensa/esp32s3/esp32s3-devkit/configs/sta_softap/defconfig | 3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)
@@ -1087,34 +1087,39 @@ static void esp_semphr_delete(void *semphr)
  *
  * Input Parameters:
- *   semphr - Semaphore data pointer
- *   ticks  - Wait system ticks
+ *   semphr          - Semaphore data pointer
+ *   block_time_tick - Wait system ticks
  *
  * Returned Value:
